@@ -7,14 +7,13 @@ CREATE TABLE IF NOT EXISTS `sccpdevices` (
   `transfer` varchar(5) default 'on',
   `cfwdall` varchar(5) default 'on',
   `cfwdbusy` varchar(5) default 'on',
-  `dtmfmode` varchar(10) default NULL,
   `imageversion` varchar(45) default NULL,
   `deny` varchar(45) default NULL,
   `permit` varchar(45) default NULL,
   `dndFeature` varchar(5) default 'on',
   `trustphoneip` varchar(100) default NULL,
   `directrtp` varchar(3) default 'off',
-  `earlyrtp` varchar(8) default 'off',
+  `earlyrtp` varchar(10) default 'progress',
   `mwilamp` varchar(5) default 'on',
   `mwioncall` varchar(5) default 'off',
   `pickupexten` varchar(5) default 'on',
