@@ -6,13 +6,12 @@ CREATE TABLE sccpdevice (
   transfer 			varchar(5) 	DEFAULT 'on',
   cfwdall 			varchar(5) 	DEFAULT 'on',
   cfwdbusy 			varchar(5) 	DEFAULT 'on',
-  dtmfmode 			varchar(10) 	DEFAULT NULL,
   imageversion			varchar(45) 	DEFAULT NULL,
   deny 				varchar(45) 	DEFAULT NULL,
   permit 			varchar(45) 	DEFAULT NULL,
   dndFeature 			varchar(5) 	DEFAULT 'on',
   directrtp 			varchar(3) 	DEFAULT 'off',
-  earlyrtp 			varchar(8) 	DEFAULT 'off',
+  earlyrtp 			varchar(10) 	DEFAULT 'progress',
   mwilamp 			varchar(5) 	DEFAULT 'on',
   mwioncall 			varchar(5) 	DEFAULT 'off',
   pickupexten			varchar(5) 	DEFAULT 'on',
