@@ -14,8 +14,8 @@
  * When to use:	Methods communicating to asterisk about module initialization, status, destruction
  * Relations:	Main hub for all other sourcefiles.
  *
- * $Date: 2014-05-02 09:48:10 +0200 (Fri, 02 May 2014) $
- * $Revision: 5398 $
+ * $Date: 2014-06-22 12:58:33 +0200 (Sun, 22 Jun 2014) $
+ * $Revision: 5502 $
  */
 
 #include <config.h>
@@ -48,12 +48,13 @@
 #include "revision.h"
 #include <signal.h>
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5398 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5502 $")
 
-#define GENERATE_ENUM_STRINGS
+#define ENUMMACRO_FILE "chan_sccp_enums.hh"
+#define ENUMMACRO_GENERATE ENUMMACRO_GENFUNCTION
 #include "sccp_enum_macro.h"
-#include "chan_sccp_enums.hh"
-#undef GENERATE_ENUM_STRINGS
+#undef  ENUMMACRO_GENERATE
+#undef  ENUMMACRO_FILE
 
 /*!
  * \brief       Buffer for Jitterbuffer use
@@ -173,9 +174,7 @@ sccp_channel_request_status_t sccp_requestChannel(const char *lineName, skinny_c
 	my_sccp_channel->autoanswer_type = autoanswer_type;
 	my_sccp_channel->autoanswer_cause = autoanswer_cause;
 	my_sccp_channel->ringermode = ringermode;
-#ifdef CS_EXPERIMENTAL
 	my_sccp_channel->hangupRequest = sccp_wrapper_asterisk_requestQueueHangup;
-#endif	
 	l = sccp_line_release(l);
 
 	return SCCP_REQUEST_STATUS_SUCCESS;
@@ -600,7 +599,7 @@ boolean_t sccp_prePBXLoad(void)
 	GLOB(amaflags) = pbx_channel_string2amaflag("documentation");
 	GLOB(callanswerorder) = ANSWER_OLDEST_FIRST;
 	GLOB(socket_thread) = AST_PTHREADT_NULL;
-	GLOB(earlyrtp) = SCCP_CHANNELSTATE_PROGRESS;
+	GLOB(earlyrtp) = SCCP_EARLYRTP_PROGRESS;
 	sccp_create_hotline();
 	return TRUE;
 }
