@@ -9,8 +9,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2010-10-23 20:04:30 +0200 (Sat, 23 Oct 2010) $
- * $Revision: 2044 $  
+ * $Date: 2014-06-24 13:32:51 +0200 (Tue, 24 Jun 2014) $
+ * $Revision: 5513 $  
  */
 #include <config.h>
 #include "../../common.h"
@@ -19,8 +19,9 @@
 #include "../../sccp_utils.h"
 #include "../../sccp_indicate.h"
 #include "../../sccp_socket.h"
+#include "../../sccp_pbx.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 2269 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5513 $")
 
 /*
  * \brief itterate through locked pbx channels
@@ -429,19 +430,51 @@ sccp_channel_t *get_sccp_channel_from_pbx_channel(const PBX_CHANNEL_TYPE * pbx_c
 	}
 }
 
-#ifdef CS_EXPERIMENTAL
-boolean_t sccp_wrapper_asterisk_dummyHangup(sccp_channel_t *channel)
+static boolean_t sccp_wrapper_asterisk_nullHangup(sccp_channel_t *channel)
 {
-	pbx_log(LOG_NOTICE, "%s: hangup request, replaced by dummy. Hangup not performed\n", channel->designator);
 	return FALSE;
 }
 
+static boolean_t sccp_wrapper_asterisk_carefullHangup(sccp_channel_t *channel)
+{
+	boolean_t res = FALSE;
+	if (!channel || !channel->owner) {
+		return FALSE;
+	}
+	PBX_CHANNEL_TYPE *pbx_channel = ast_channel_ref(channel->owner);
+
+	/* let's wait for a bit, for the dust to settle */
+	sched_yield();
+	pbx_safe_sleep(pbx_channel, 10000);
+
+	/* recheck everything before going forward */
+	pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) processing hangup request, using carefull version. Standby.\n", pbx_channel_name(pbx_channel));
+	if (!ast_check_hangup(pbx_channel)) {
+		pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Channel still active.\n", pbx_channel_name(pbx_channel));
+		if (!pbx_test_flag(pbx_channel_flags(pbx_channel), AST_FLAG_IN_AUTOLOOP) && !pbx_channel_pbx(pbx_channel)) {
+			pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Has no PBX -> ast_hangup.\n", pbx_channel_name(pbx_channel));
+			ast_hangup(pbx_channel);
+			res = TRUE;
+		} else {
+			pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Has PBX -> ast_queue_hangup.\n", pbx_channel_name(pbx_channel));
+			res = ast_queue_hangup(pbx_channel) ? FALSE : TRUE;
+		}
+	} else {
+		pbx_log(LOG_NOTICE, "%s: (sccp_wrapper_asterisk_carefullHangup) Already Hungup. Forcing SCCP Remove Call.\n", pbx_channel_name(pbx_channel));
+		channel->hangupRequest = sccp_wrapper_asterisk_nullHangup;
+		sccp_pbx_hangup(channel);
+		res = TRUE; 
+	}
+	ast_channel_unref(pbx_channel);
+	return res;
+}
+
 boolean_t sccp_wrapper_asterisk_requestQueueHangup(sccp_channel_t *channel)
 {
 	boolean_t res = FALSE;
 	PBX_CHANNEL_TYPE *pbx_channel = channel->owner;
 
-	channel->hangupRequest = sccp_wrapper_asterisk_dummyHangup;
+	channel->hangupRequest = sccp_wrapper_asterisk_carefullHangup;
 	if (!ast_check_hangup(pbx_channel)) {							/* if channel is not already been hungup */
 		res = ast_queue_hangup(pbx_channel) ? FALSE : TRUE;
 	} else {
@@ -450,81 +483,15 @@ boolean_t sccp_wrapper_asterisk_requestQueueHangup(sccp_channel_t *channel)
 	return res;
 }
 
-// carefull version of sccp_wrapper_asterisk_requestHangup, when ast_pbx_start has been requested.
-boolean_t sccp_wrapper_asterisk_requestHangup_PBXStarting(sccp_channel_t *channel)
-{
-	PBX_CHANNEL_TYPE *pbx_channel = channel->owner;
-	channel->hangupRequest = sccp_wrapper_asterisk_dummyHangup;
-	if (!pbx_test_flag(pbx_channel_flags(pbx_channel), AST_FLAG_IN_AUTOLOOP) && !pbx_channel_pbx(pbx_channel) && !pbx_check_hangup(pbx_channel)) {
-		ast_hangup(channel->owner);
-	} else {
-		sccp_wrapper_asterisk_requestQueueHangup(channel);
-	}
-	return TRUE;
-}
-
 boolean_t sccp_wrapper_asterisk_requestHangup(sccp_channel_t *channel)
 {
-	channel->hangupRequest = sccp_wrapper_asterisk_dummyHangup;
-	ast_hangup(channel->owner);
+	PBX_CHANNEL_TYPE *pbx_channel = channel->owner;
+	channel->hangupRequest = sccp_wrapper_asterisk_carefullHangup;
+	if (!ast_check_hangup(pbx_channel)) {
+		ast_hangup(pbx_channel);
+	}
 	return TRUE;
 }
-#else
-int sccp_wrapper_asterisk_requestHangup(PBX_CHANNEL_TYPE * ast_channel)
-{
-	if (!ast_channel) {
-		pbx_log(LOG_NOTICE, "channel to hangup is NULL\n");
-		return FALSE;
-	}
-
-	if ((pbx_channel_softhangup(ast_channel) & AST_SOFTHANGUP_APPUNLOAD) != 0) {
-		pbx_channel_set_hangupcause(ast_channel, AST_CAUSE_CHANNEL_UNACCEPTABLE);
-		ast_softhangup(ast_channel, AST_SOFTHANGUP_APPUNLOAD);
-		sccp_log((DEBUGCAT_CORE)) (VERBOSE_PREFIX_3 "%s: send softhangup appunload\n", pbx_channel_name(ast_channel));
-		return TRUE;
-	}
-
-	sccp_channel_t *sccp_channel = get_sccp_channel_from_pbx_channel(ast_channel);
-
-	sccp_log((DEBUGCAT_CHANNEL)) (VERBOSE_PREFIX_3 "hangup %s: hasPbx %s; ast state: %s, sccp state: %s, blocking: %s, already being hungup: %s, hangupcause: %d\n",
-				      pbx_channel_name(ast_channel), pbx_channel_pbx(ast_channel) ? "yes" : "no", pbx_state2str(pbx_channel_state(ast_channel)), sccp_channel ? sccp_indicate2str(sccp_channel->state) : "--", pbx_test_flag(pbx_channel_flags(ast_channel), AST_FLAG_BLOCKING) ? "yes" : "no", pbx_channel_softhangup(ast_channel) ? "yes" : "no", pbx_channel_hangupcause(ast_channel)
-	    );
-
-	if (pbx_test_flag(pbx_channel_flags(ast_channel), AST_FLAG_BLOCKING)) {
-		// wait for blocker before issuing softhangup
-		int tries = 0;
-
-		while (!pbx_channel_blocker(ast_channel) && tries < 50) {
-			sccp_log((DEBUGCAT_CHANNEL)) (VERBOSE_PREFIX_3 "SCCP: (requestHangup) Blocker set but no blocker found yet, waiting...!\n");
-			usleep(50);
-			tries++;
-		}
-		sccp_log((DEBUGCAT_CHANNEL)) (VERBOSE_PREFIX_3 "%s: send ast_softhangup_nolock (blocker: %s)\n", pbx_channel_name(ast_channel), pbx_channel_blockproc(ast_channel));
-		ast_softhangup_nolock(ast_channel, AST_SOFTHANGUP_DEV);
-	} else if (AST_STATE_UP == pbx_channel_state(ast_channel) || pbx_channel_pbx(ast_channel)) {
-		sccp_log((DEBUGCAT_CHANNEL)) (VERBOSE_PREFIX_3 "%s: send ast_queue_hangup\n", pbx_channel_name(ast_channel));
-#if ASTERISK_VERSION_NUMBER < 10601
-		pbx_channel_setwhentohangup_tv(ast_channel, 0);
-#else
-		pbx_channel_setwhentohangup_tv(ast_channel, ast_tvnow());
-#endif
-		ast_queue_hangup(ast_channel);
-	} else {
-		sccp_log((DEBUGCAT_CHANNEL)) (VERBOSE_PREFIX_3 "%s: send hard ast_hangup\n", pbx_channel_name(ast_channel));
-		if (!pbx_channel_pbx(ast_channel)) {
-			ast_channel_lock(ast_channel);
-			ast_indicate(ast_channel, -1);
-			ast_hangup(ast_channel);
-			ast_channel_unlock(ast_channel);
-		} else {
-			ast_queue_hangup(ast_channel);
-		}
-	}
-
-	sccp_channel = sccp_channel ? sccp_channel_release(sccp_channel) : NULL;
-	return TRUE;
-}
-#endif
 
 int sccp_asterisk_pbx_fktChannelWrite(PBX_CHANNEL_TYPE * ast, const char *funcname, char *args, const char *value)
 {
@@ -745,7 +712,7 @@ int sccp_wrapper_asterisk_channel_read(PBX_CHANNEL_TYPE * ast, NEWCONST char *fu
 			} else if (!strcasecmp(args, "recvip")) {
 				ast_copy_string(buf, sccp_socket_stringify(&d->session->sin), buflen);
 			} else if (!strcasecmp(args, "useragent")) {
-				sccp_copy_string(buf, devicetype2str(d->skinny_type), buflen);
+				sccp_copy_string(buf, skinny_devicetype2str(d->skinny_type), buflen);
 			} else if (!strcasecmp(args, "from")) {
 				sccp_copy_string(buf, (char *) d->id, buflen);
 			} else {
@@ -825,7 +792,6 @@ static int sccp_asterisk_doPickup(PBX_CHANNEL_TYPE *pbx_channel) {
 	return TRUE;
 }
 
-#ifdef CS_EXPERIMENTAL
 enum ast_pbx_result pbx_pbx_start (PBX_CHANNEL_TYPE *pbx_channel) {
 	enum ast_pbx_result res = AST_PBX_FAILED;
 	sccp_channel_t *channel = NULL;
@@ -855,7 +821,7 @@ enum ast_pbx_result pbx_pbx_start (PBX_CHANNEL_TYPE *pbx_channel) {
 			goto EXIT;
 		}
 //		channel->hangupRequest = sccp_wrapper_asterisk_dummyHangup;
-		channel->hangupRequest = sccp_wrapper_asterisk_requestHangup_PBXStarting;
+		channel->hangupRequest = sccp_wrapper_asterisk_carefullHangup;
 		res = ast_pbx_start(pbx_channel);			// starting ast_pbx_start with a locked ast_channel so we know exactly where we end up when/if the __ast_pbx_run get started
 		if (res == 0) {						// thread started successfully
 			do {						// wait for thread to become ready
@@ -879,36 +845,5 @@ enum ast_pbx_result pbx_pbx_start (PBX_CHANNEL_TYPE *pbx_channel) {
 EXIT:
 	return res;
 }
-#else
-enum ast_pbx_result pbx_pbx_start (PBX_CHANNEL_TYPE *pbx_channel) {
-	enum ast_pbx_result res = AST_PBX_FAILED;
-	sccp_channel_t *channel = NULL;
-
-	if (!pbx_channel) {
-		pbx_log(LOG_ERROR, "SCCP: (pbx_pbx_start) called without pbx channel\n");
-		return res;
-	}
-	
-	if((channel = get_sccp_channel_from_pbx_channel(pbx_channel))){
-		ast_channel_lock(pbx_channel);
-		const char *dialedNumber = PBX(getChannelExten)(channel);
-		char *pickupexten = "";
-		if (PBX(getPickupExtension)(channel, &pickupexten) && sccp_strequals(dialedNumber, pickupexten)) {
-			if (sccp_asterisk_doPickup(pbx_channel)) {
-				res = AST_PBX_SUCCESS;
-			}
-			ast_channel_unlock(pbx_channel);
-			channel = sccp_channel_release(channel);
-			sccp_free(pickupexten);
-			goto EXIT;
-		}
-		ast_channel_unlock(pbx_channel);
-		channel = sccp_channel_release(channel);
-	}
-	res = ast_pbx_start(pbx_channel);
-EXIT:
-	return res;
-}
-#endif
  
 // kate: indent-width 4; replace-tabs off; indent-mode cstyle; auto-insert-doxygen on; line-numbers on; tab-indents on; keep-extra-spaces off;
