@@ -10,8 +10,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License. 
  *		See the LICENSE file at the top of the source tree.
  * 
- * $Date: 2011-01-12 02:42:50 +0100 (Mi, 12 Jan 2011) $
- * $Revision: 2235 $
+ * $Date: 2014-06-22 12:58:33 +0200 (Sun, 22 Jun 2014) $
+ * $Revision: 5502 $
  */
 #include <config.h>
 #include "common.h"
@@ -23,7 +23,7 @@
 #include "sccp_conference.h"
 #include "sccp_socket.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 2235 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5502 $")
 
 /*!
  * \brief  ${SCCPDEVICE()} Dialplan function - reads device data 
@@ -42,7 +42,6 @@ SCCP_FILE_VERSION(__FILE__, "$Revision: 2235 $")
  */
 static int sccp_func_sccpdevice(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, char *data, char *buf, size_t len)
 {
-	sccp_device_t *d = NULL;
 	char *colname;
 	char tmp[1024] = "";
 	char lbuf[1024] = "";
@@ -61,20 +60,18 @@ static int sccp_func_sccpdevice(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, cha
 		colname = "ip";
 	}
 
+	AUTO_RELEASE sccp_device_t *d = NULL;
 	if (!strncasecmp(data, "current", 7)) {
-		sccp_channel_t *c;
-
-		if (!(c = get_sccp_channel_from_pbx_channel(chan))) {
-			/*pbx_log(LOG_WARNING, "SCCPDEVICE(): Not an SCCP channel\n"); */
+		AUTO_RELEASE sccp_channel_t *c = get_sccp_channel_from_pbx_channel(chan);
+		if (c) {
+			if (!(d = sccp_channel_getDevice_retained(c))) {
+				pbx_log(LOG_WARNING, "SCCPDEVICE(): SCCP Device not available\n");
+				return -1;
+			}
+		} else {
+			/* pbx_log(LOG_WARNING, "SCCPDEVICE(): No current SCCP channel found\n"); */
 			return -1;
 		}
-
-		if (!(d = sccp_channel_getDevice_retained(c))) {
-			pbx_log(LOG_WARNING, "SCCPDEVICE(): SCCP Device not available\n");
-			c = sccp_channel_release(c);
-			return -1;
-		}
-		c = sccp_channel_release(c);
 	} else {
 		if (!(d = sccp_device_find_byid(data, FALSE))) {
 			pbx_log(LOG_WARNING, "SCCPDEVICE(): SCCP Device not available\n");
@@ -91,27 +88,27 @@ static int sccp_func_sccpdevice(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, cha
 		} else if (!strcasecmp(colname, "id")) {
 			sccp_copy_string(buf, d->id, len);
 		} else if (!strcasecmp(colname, "status")) {
-			sccp_copy_string(buf, devicestate2str(d->state), len);
+			sccp_copy_string(buf, sccp_devicestate2str(d->state), len);
 		} else if (!strcasecmp(colname, "description")) {
 			sccp_copy_string(buf, d->description, len);
 		} else if (!strcasecmp(colname, "config_type")) {
 			sccp_copy_string(buf, d->config_type, len);
 		} else if (!strcasecmp(colname, "skinny_type")) {
-			sccp_copy_string(buf, devicetype2str(d->skinny_type), len);
+			sccp_copy_string(buf, skinny_devicetype2str(d->skinny_type), len);
 		} else if (!strcasecmp(colname, "tz_offset")) {
 			snprintf(buf, len, "%d", d->tz_offset);
 		} else if (!strcasecmp(colname, "image_version")) {
 			sccp_copy_string(buf, d->imageversion, len);
 		} else if (!strcasecmp(colname, "accessory_status")) {
-			sccp_copy_string(buf, accessorystate2str(d->accessorystatus), len);
+			sccp_copy_string(buf, sccp_accessorystate2str(d->accessorystatus), len);
 		} else if (!strcasecmp(colname, "registration_state")) {
-			sccp_copy_string(buf, registrationstate2str(d->registrationState), len);
+			sccp_copy_string(buf, skinny_registrationstate2str(d->registrationState), len);
 		} else if (!strcasecmp(colname, "codecs")) {
 			sccp_multiple_codecs2str(buf, sizeof(buf) - 1, d->preferences.audio, ARRAY_LEN(d->preferences.audio));
 		} else if (!strcasecmp(colname, "capability")) {
 			sccp_multiple_codecs2str(buf, len - 1, d->capabilities.audio, ARRAY_LEN(d->capabilities.audio));
 		} else if (!strcasecmp(colname, "state")) {
-			sccp_copy_string(buf, accessorystate2str(d->accessorystatus), len);
+			sccp_copy_string(buf, sccp_accessorystate2str(d->accessorystatus), len);
 		} else if (!strcasecmp(colname, "lines_registered")) {
 			sccp_copy_string(buf, d->linesRegistered ? "yes" : "no", len);
 		} else if (!strcasecmp(colname, "lines_count")) {
@@ -119,7 +116,7 @@ static int sccp_func_sccpdevice(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, cha
 		} else if (!strcasecmp(colname, "last_number")) {
 			sccp_copy_string(buf, d->lastNumber, len);
 		} else if (!strcasecmp(colname, "early_rtp")) {
-			snprintf(buf, len, "%d", d->earlyrtp);
+			snprintf(buf, len, "%s", sccp_earlyrtp2str(d->earlyrtp));
 		} else if (!strcasecmp(colname, "supported_protocol_version")) {
 			snprintf(buf, len, "%d", d->protocolversion);
 		} else if (!strcasecmp(colname, "used_protocol_version")) {
@@ -129,7 +126,7 @@ static int sccp_func_sccpdevice(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, cha
 		} else if (!strcasecmp(colname, "dnd_feature")) {
 			sccp_copy_string(buf, (d->dndFeature.enabled) ? "ON" : "OFF", len);
 		} else if (!strcasecmp(colname, "dnd_state")) {
-			sccp_copy_string(buf, dndmode2str(d->dndFeature.status), len);
+			sccp_copy_string(buf, sccp_dndmode2str(d->dndFeature.status), len);
 		} else if (!strcasecmp(colname, "dynamic") || !strcasecmp(colname, "realtime")) {
 	#ifdef CS_SCCP_REALTIME
 			sccp_copy_string(buf, d->realtime ? "yes" : "no", len);
@@ -169,19 +166,21 @@ static int sccp_func_sccpdevice(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, cha
 			SCCP_LIST_TRAVERSE(&d->buttonconfig, config, list) {
 				switch (config->type) {
 					case LINE:
-						snprintf(tmp, sizeof(tmp), "[%d,%s,%s]", config->instance, config_buttontype2str(config->type), config->button.line.name);
+						snprintf(tmp, sizeof(tmp), "[%d,%s,%s]", config->instance, sccp_config_buttontype2str(config->type), config->button.line.name);
 						break;
 					case SPEEDDIAL:
-						snprintf(tmp, sizeof(tmp), "[%d,%s,%s,%s]", config->instance, config_buttontype2str(config->type), config->label, config->button.speeddial.ext);
+						snprintf(tmp, sizeof(tmp), "[%d,%s,%s,%s]", config->instance, sccp_config_buttontype2str(config->type), config->label, config->button.speeddial.ext);
 						break;
 					case SERVICE:
-						snprintf(tmp, sizeof(tmp), "[%d,%s,%s,%s]", config->instance, config_buttontype2str(config->type), config->label, config->button.service.url);
+						snprintf(tmp, sizeof(tmp), "[%d,%s,%s,%s]", config->instance, sccp_config_buttontype2str(config->type), config->label, config->button.service.url);
 						break;
 					case FEATURE:
-						snprintf(tmp, sizeof(tmp), "[%d,%s,%s,%s]", config->instance, config_buttontype2str(config->type), config->label, config->button.feature.options);
+						snprintf(tmp, sizeof(tmp), "[%d,%s,%s,%s]", config->instance, sccp_config_buttontype2str(config->type), config->label, config->button.feature.options);
 						break;
 					case EMPTY:
-						snprintf(tmp, sizeof(tmp), "[%d,%s]", config->instance, config_buttontype2str(config->type));
+						snprintf(tmp, sizeof(tmp), "[%d,%s]", config->instance, sccp_config_buttontype2str(config->type));
+						break;
+					case sccp_config_buttontype_LOOKUPERROR:
 						break;
 				}
 				if (first == 0) {
@@ -227,7 +226,6 @@ static int sccp_func_sccpdevice(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, cha
 			pbx_log(LOG_WARNING, "SCCPDEVICE(%s): unknown colname: %s\n", data, colname);
 			buf[0] = '\0';
 		}
-		sccp_device_release(d);
 	}
 	return 0;
 }
@@ -264,8 +262,6 @@ static struct pbx_custom_function sccpdevice_function = {
  */
 static int sccp_func_sccpline(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, char *data, char *buf, size_t len)
 {
-	sccp_line_t *l = NULL;
-	sccp_channel_t *c = NULL;
 	char *colname;
 	char tmp[1024] = "";
 	char lbuf[1024] = "";
@@ -283,20 +279,19 @@ static int sccp_func_sccpline(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, char
 	} else {
 		colname = "id";
 	}
+	AUTO_RELEASE sccp_line_t *l = NULL;
+	AUTO_RELEASE sccp_channel_t *c = NULL;
 	if (!strncasecmp(data, "current", 7)) {
 		if (!(c = get_sccp_channel_from_pbx_channel(chan))) {
-
 			/* pbx_log(LOG_WARNING, "SCCPLINE(): Not an SCCP Channel\n"); */
 			return -1;
 		}
 
 		if (!c->line) {
 			pbx_log(LOG_WARNING, "SCCPLINE(): SCCP Line not available\n");
-			c = sccp_channel_release(c);
 			return -1;
 		}
 		l = sccp_line_retain(c->line);
-		c = sccp_channel_release(c);
 	} else if (!strncasecmp(data, "parent", 7)) {
 		if (!(c = get_sccp_channel_from_pbx_channel(chan))) {
 
@@ -306,11 +301,9 @@ static int sccp_func_sccpline(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, char
 
 		if (!c->parentChannel || !c->parentChannel->line) {
 			pbx_log(LOG_WARNING, "SCCPLINE(): SCCP Line not available\n");
-			c = sccp_channel_release(c);
 			return -1;
 		}
 		l = sccp_line_retain(c->parentChannel->line);
-		c = sccp_channel_release(c);
 	} else {
 		if (!(l = sccp_line_find_byname(data, TRUE))) {
 			pbx_log(LOG_WARNING, "SCCPLINE(): SCCP Line not available\n");
@@ -440,7 +433,6 @@ static int sccp_func_sccpline(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, char
 			pbx_log(LOG_WARNING, "SCCPLINE(%s): unknown colname: %s\n", data, colname);
 			buf[0] = '\0';
 		}
-		sccp_line_release(l);
 	}
 	return 0;
 }
@@ -473,8 +465,6 @@ static struct pbx_custom_function sccpline_function = {
  */
 static int sccp_func_sccpchannel(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, char *data, char *buf, size_t len)
 {
-	sccp_channel_t *c = NULL;
-	sccp_device_t *d = NULL;
 	PBX_CHANNEL_TYPE *ast;
 	char *colname;
 	
@@ -491,7 +481,7 @@ static int sccp_func_sccpchannel(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, ch
 		colname = "callid";
 	}
 	
-	
+	AUTO_RELEASE sccp_channel_t *c = NULL;
 	if (!strncasecmp(data, "current", 7)) {
 		if (!(c = get_sccp_channel_from_pbx_channel(chan))) {
 			return -1;										/* Not a SCCP channel. */
@@ -509,6 +499,7 @@ static int sccp_func_sccpchannel(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, ch
 	}
 	
 	if (c) {
+		AUTO_RELEASE sccp_device_t *d = NULL;
 		if (!strcasecmp(colname, "callid") || !strcasecmp(colname, "id")) {
 			snprintf(buf, len, "%d", c->callid);
 		} else if (!strcasecmp(colname, "format")) {
@@ -548,11 +539,11 @@ static int sccp_func_sccpchannel(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, ch
 		} else if (!strcasecmp(colname, "passthrupartyid")) {
 			snprintf(buf, len, "%d", c->passthrupartyid);
 		} else if (!strcasecmp(colname, "state")) {
-			sccp_copy_string(buf, channelstate2str(c->state), len);
+			sccp_copy_string(buf, sccp_channelstate2str(c->state), len);
 		} else if (!strcasecmp(colname, "previous_state")) {
-			sccp_copy_string(buf, channelstate2str(c->previousChannelState), len);
+			sccp_copy_string(buf, sccp_channelstate2str(c->previousChannelState), len);
 		} else if (!strcasecmp(colname, "calltype")) {
-			sccp_copy_string(buf, calltype2str(c->calltype), len);
+			sccp_copy_string(buf, skinny_calltype2str(c->calltype), len);
 		} else if (!strcasecmp(colname, "dialed_number")) {
 			sccp_copy_string(buf, c->dialedNumber, len);
 		} else if (!strcasecmp(colname, "device")) {
@@ -580,13 +571,10 @@ static int sccp_func_sccpchannel(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, ch
 		} else if (!strcasecmp(colname, "peerip")) {								// NO-NAT (Ip-Address Associated with the Session->sin)
 			if ((d = sccp_channel_getDevice_retained(c))) {
 				sccp_copy_string(buf, sccp_socket_stringify(&d->session->sin), len);
-				
-				d = sccp_device_release(d);
 			}
 		} else if (!strcasecmp(colname, "recvip")) {								// NAT (Actual Source IP-Address Reported by the phone upon registration)
 			if ((d = sccp_channel_getDevice_retained(c))) {
 				ast_copy_string(buf, sccp_socket_stringify(&d->session->sin), len);
-				d = sccp_device_release(d);
 			}
 		} else if (!strncasecmp(colname, "codec[", 6)) {
 			char *codecnum;
@@ -606,7 +594,6 @@ static int sccp_func_sccpchannel(PBX_CHANNEL_TYPE * chan, NEWCONST char *cmd, ch
 			pbx_log(LOG_WARNING, "SCCPCHANNEL(%s): unknown colname: %s\n", data, colname);
 			buf[0] = '\0';
 		}
-		sccp_channel_release(c);
 	}
 	return 0;
 }
@@ -642,7 +629,7 @@ static int sccp_app_prefcodec(PBX_CHANNEL_TYPE * chan, const char *data)
 static int sccp_app_prefcodec(PBX_CHANNEL_TYPE * chan, void *data)
 #endif
 {
-	sccp_channel_t *c = NULL;
+	AUTO_RELEASE sccp_channel_t *c = NULL;
 	int res;
 
 	if (!(c = get_sccp_channel_from_pbx_channel(chan))) {
@@ -651,7 +638,6 @@ static int sccp_app_prefcodec(PBX_CHANNEL_TYPE * chan, void *data)
 	}
 
 	res = sccp_channel_setPreferredCodec(c, data);
-	c = sccp_channel_release(c);
 	pbx_log(LOG_WARNING, "SCCPSetCodec: Is now deprecated. Please use 'Set(CHANNEL(codec)=%s)' insteadl.\n", (char *) data);
 	return res ? 0 : -1;
 }
@@ -678,7 +664,7 @@ static int sccp_app_calledparty(PBX_CHANNEL_TYPE * chan, void *data)
 {
 	char *text = (char *) data;
 	char *num, *name;
-	sccp_channel_t *c = NULL;
+	AUTO_RELEASE sccp_channel_t *c = NULL;
 
 	if (!(c = get_sccp_channel_from_pbx_channel(chan))) {
 		pbx_log(LOG_WARNING, "SCCPSetCalledParty: Not an SCCP channel\n");
@@ -687,14 +673,11 @@ static int sccp_app_calledparty(PBX_CHANNEL_TYPE * chan, void *data)
 
 	if (!text) {
 		pbx_log(LOG_WARNING, "SCCPSetCalledParty: No CalledParty Information Provided\n");
-		c = sccp_channel_release(c);
 		return 0;
 	}
 
 	pbx_callerid_parse(text, &name, &num);
 	sccp_channel_set_calledparty(c, name, num);
-	c = sccp_channel_release(c);
-
 	return 0;
 }
 
@@ -719,8 +702,7 @@ static int sccp_app_setmessage(PBX_CHANNEL_TYPE * chan, const char *data)
 static int sccp_app_setmessage(PBX_CHANNEL_TYPE * chan, void *data)
 #endif
 {
-	sccp_channel_t *c = NULL;
-	sccp_device_t *d;
+	AUTO_RELEASE sccp_channel_t *c = NULL;
 
 	if (!(c = get_sccp_channel_from_pbx_channel(chan))) {
 		pbx_log(LOG_WARNING, "SCCPSetMessage: Not an SCCP channel\n");
@@ -736,9 +718,9 @@ static int sccp_app_setmessage(PBX_CHANNEL_TYPE * chan, void *data)
 		timeout = atoi(splitter);
 	}
 
+	AUTO_RELEASE sccp_device_t *d = NULL;
 	if (!text || !(d = sccp_channel_getDevice_retained(c))) {
 		pbx_log(LOG_WARNING, "SCCPSetMessage: Not an SCCP device or not text provided\n");
-		c = sccp_channel_release(c);
 		return 0;
 	}
 	if (text[0] != '\0') {
@@ -746,9 +728,6 @@ static int sccp_app_setmessage(PBX_CHANNEL_TYPE * chan, void *data)
 	} else {
 		sccp_dev_clear_message(d, TRUE);
 	}
-
-	d = sccp_device_release(d);
-	c = sccp_channel_release(c);
 	return 0;
 }
 
