@@ -15,8 +15,8 @@
  * Relations:	SCCP Device -> SCCP DeviceLine -> SCCP Line
  * 		SCCP Line -> SCCP ButtonConfig -> SCCP Device
  *
- * \date	$Date: 2014-06-27 00:32:10 +0200 (Fri, 27 Jun 2014) $
- * \version     $Revision: 5526 $
+ * \date	$Date: 2014-06-28 18:34:10 +0200 (Sat, 28 Jun 2014) $
+ * \version     $Revision: 5536 $
  */
 
 #include <config.h>
@@ -32,7 +32,7 @@
 #include "sccp_indicate.h"
 #include "sccp_mwi.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5526 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5536 $")
 int __sccp_device_destroy(const void *ptr);
 void sccp_device_removeFromGlobals(sccp_device_t * device);
 int sccp_device_destroy(const void *ptr);
@@ -299,7 +299,7 @@ void sccp_device_pre_reload(void)
 /*!
  * \brief Check Device Update Status
  * \note See \ref sccp_config_reload
- * \param d SCCP Device
+ * \param device SCCP Device
  * \return Result as Boolean
  *
  * \callgraph
@@ -1691,7 +1691,7 @@ void sccp_dev_forward_status(sccp_line_t * l, uint8_t lineInstance, sccp_device_
 
 /*!
  * \brief Check Ringback on Device
- * \param d SCCP Device
+ * \param device SCCP Device
  * \return Result as int
  */
 int sccp_device_check_ringback(sccp_device_t * device)
@@ -1821,7 +1821,7 @@ void sccp_dev_postregistration(void *data)
  *  clean up memory allocated by the device.
  *  if destroy is true, device will be removed from global device list
  *
- * \param d SCCP Device
+ * \param device SCCP Device
  * \param remove_from_global as boolean_t
  * \param cleanupTime Clean-up Time as uint8
  *
@@ -2343,6 +2343,7 @@ static void sccp_device_indicate_onhook(const sccp_device_t * device, const sccp
 	if (channel && channel == device->active_channel) {
 		sccp_dev_set_speaker(device, SKINNY_STATIONSPEAKER_OFF);
 	}
+	sccp_device_clearMessageFromStack(device, SCCP_MESSAGE_PRIORITY_PRIVACY);
 	sccp_dev_check_displayprompt(device);						/* see if we need to display anything from the messageStack */
 }
 
@@ -2522,7 +2523,7 @@ void sccp_device_featureChangedDisplay(const sccp_event_t * event)
 				sccp_device_clearMessageFromStack(device, SCCP_MESSAGE_PRIORITY_DND);
 			} else {
 				if (device->dndFeature.status == SCCP_DNDMODE_SILENT) {
-					sccp_device_addMessageToStack(device, SCCP_MESSAGE_PRIORITY_DND, ">>> " SKINNY_DISP_DND " (Silent) <<<");
+					sccp_device_addMessageToStack(device, SCCP_MESSAGE_PRIORITY_DND, ">>> " SKINNY_DISP_DND " (" SKINNY_DISP_SILENT ") <<<");
 				} else {
 					sccp_device_addMessageToStack(device, SCCP_MESSAGE_PRIORITY_DND, ">>> " SKINNY_DISP_DND " (" SKINNY_DISP_BUSY ") <<<");
 				}
@@ -2537,7 +2538,8 @@ void sccp_device_featureChangedDisplay(const sccp_event_t * event)
 			break;
 		case SCCP_FEATURE_MONITOR:
 			if (device->monitorFeature.status) {
-				sccp_device_addMessageToStack(device, SCCP_MESSAGE_PRIORITY_MONITOR, SKINNY_DISP_MONITOR);
+//				sccp_device_addMessageToStack(device, SCCP_MESSAGE_PRIORITY_MONITOR, SKINNY_DISP_MONITOR);
+				sccp_device_addMessageToStack(device, SCCP_MESSAGE_PRIORITY_MONITOR, SKINNY_DISP_RECORDING);
 			} else {
 				sccp_device_clearMessageFromStack(device, SCCP_MESSAGE_PRIORITY_MONITOR);
 			}
@@ -2617,7 +2619,7 @@ static sccp_push_result_t sccp_device_pushTextMessage(const sccp_device_t * devi
  * \callgraph
  * \callergraph
  *
- * \param name Device ID (hostname)
+ * \param id Device ID (SEP.....)
  * \param useRealtime Use RealTime as Boolean
  * \return SCCP Device - can bee null if device is not found
  */
