@@ -8,8 +8,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-04-27 11:22:15 +0200 (Sun, 27 Apr 2014) $
- * $Revision: 5395 $
+ * $Date: 2014-06-27 00:32:10 +0200 (Fri, 27 Jun 2014) $
+ * $Revision: 5526 $
  */
 
 #ifndef __SCCP_DEVICE_H
@@ -27,7 +27,7 @@ struct sccp_device_indication_cb {
 	void (*const remoteOffhook) (const sccp_device_t * device, sccp_linedevices_t * linedevice, const sccp_channel_t * channel);
 	void (*const remoteOnhook) (const sccp_device_t * device, sccp_linedevices_t * linedevice, const sccp_channel_t * channel);
 	void (*const offhook) (const sccp_device_t * device, sccp_linedevices_t * linedevice, uint8_t callid);
-	void (*const onhook) (const sccp_device_t * device, const uint8_t lineInstance, uint8_t callid);
+	void (*const onhook) (const sccp_device_t * device, const sccp_channel_t *channel, const uint8_t lineInstance, uint8_t callid);
 	void (*const dialing) (const sccp_device_t *device, const uint8_t lineInstance, const sccp_channel_t *channel);
 	void (*const proceed) (const sccp_device_t *device, const uint8_t lineInstance, const sccp_channel_t *channel);
 	void (*const connected) (const sccp_device_t * device, sccp_linedevices_t * linedevice, const sccp_channel_t * channel);
@@ -55,7 +55,7 @@ void sccp_device_setActiveChannel(sccp_device_t * d, sccp_channel_t * c);
 #define REQCMD(x,y) x = sccp_build_packet(y, 0)
 sccp_msg_t *sccp_build_packet(sccp_mid_t t, size_t pkt_len);
 
-void sccp_dev_check_displayprompt(sccp_device_t * d);
+void sccp_dev_check_displayprompt(const sccp_device_t * d);
 void sccp_device_setLastNumberDialed(sccp_device_t * device, const char *lastNumberDialed);
 void sccp_device_setIndicationProtocol(sccp_device_t * device);
 void sccp_dev_build_buttontemplate(sccp_device_t * d, btnlist * btn);
@@ -85,8 +85,8 @@ void sccp_dev_clean(sccp_device_t * d, boolean_t destroy, uint8_t cleanupTime);
 void sccp_dev_keypadbutton(sccp_device_t * d, char digit, uint8_t line, uint32_t callid);
 void sccp_dev_set_message(sccp_device_t * d, const char *msg, const int timeout, const boolean_t storedb, const boolean_t beep);
 void sccp_dev_clear_message(sccp_device_t * d, const boolean_t cleardb);
-void sccp_device_addMessageToStack(sccp_device_t * device, const uint8_t priority, const char *message);
-void sccp_device_clearMessageFromStack(sccp_device_t * device, const uint8_t priority);
+void sccp_device_addMessageToStack(const sccp_device_t * device, const uint8_t priority, const char *message);
+void sccp_device_clearMessageFromStack(const sccp_device_t * device, const uint8_t priority);
 void sccp_device_featureChangedDisplay(const sccp_event_t * event);
 void sccp_device_sendcallstate(const sccp_device_t * d, uint8_t instance, uint32_t callid, uint8_t state, skinny_callpriority_t priority, skinny_callinfo_visibility_t visibility);
 
