@@ -6,8 +6,8 @@
  *		See the LICENSE file at the top of the source tree.
  * \since	2009-09-02
  *
- * $Date: 2014-04-27 11:22:15 +0200 (Sun, 27 Apr 2014) $
- * $Revision: 5395 $  
+ * $Date: 2014-06-06 11:56:09 +0200 (Fri, 06 Jun 2014) $
+ * $Revision: 5473 $  
  */
 
 #ifndef SCCP_EVENT_H_
@@ -17,8 +17,11 @@
 //#include "common.h"
 #include "chan_sccp.h"
 
+#define ENUMMACRO_FILE "sccp_event_enums.hh"
+#define ENUMMACRO_GENERATE ENUMMACRO_GENHEADER
 #include "sccp_enum_macro.h"
-#include "sccp_event_enums.hh"
+#undef  ENUMMACRO_GENERATE
+#undef  ENUMMACRO_FILE
 
 #define NUMBER_OF_EVENT_TYPES 10
 
