@@ -8,8 +8,8 @@
  *		Modified by Jan Czmok and Julien Goodwin
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *
- * $Date: 2014-06-27 00:32:10 +0200 (Fri, 27 Jun 2014) $
- * $Revision: 5526 $
+ * $Date: 2014-06-28 18:41:40 +0200 (Sat, 28 Jun 2014) $
+ * $Revision: 5537 $
  */
 
 #include <config.h>
@@ -22,7 +22,7 @@
 #include "sccp_conference.h"
 #include "sccp_actions.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5526 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5537 $")
 
 static void __sccp_indicate_remote_device(sccp_device_t * device, sccp_channel_t * c, sccp_line_t * line, uint8_t state);
 
@@ -183,11 +183,7 @@ void __sccp_indicate(sccp_device_t * device, sccp_channel_t * c, sccp_channelsta
 
 			char prompt[100];
 
-			if (c->ringermode == SKINNY_RINGTYPE_URGENT) {
-				snprintf(prompt, sizeof(prompt), "<Urgent>" SKINNY_DISP_FROM ": %s", strlen(c->callInfo.callingPartyName) ? c->callInfo.callingPartyName : c->callInfo.callingPartyNumber);
-			} else {
-				snprintf(prompt, sizeof(prompt), SKINNY_DISP_FROM ": %s", strlen(c->callInfo.callingPartyName) ? c->callInfo.callingPartyName : c->callInfo.callingPartyNumber);
-			}
+			snprintf(prompt, sizeof(prompt), "%s" SKINNY_DISP_FROM ": %s", (c->ringermode == SKINNY_RINGTYPE_URGENT) ? SKINNY_DISP_FLASH : "", strlen(c->callInfo.callingPartyName) ? c->callInfo.callingPartyName : c->callInfo.callingPartyNumber);
 			sccp_dev_displayprompt(d, instance, c->callid, prompt, GLOB(digittimeout));
 
 			PBX(set_callstate) (c, AST_STATE_RINGING);						/*!\todo thats not the right place to update pbx state */
@@ -221,7 +217,7 @@ void __sccp_indicate(sccp_device_t * device, sccp_channel_t * c, sccp_channelsta
 				if (!c->rtp.audio.rtp && d->earlyrtp <= SCCP_EARLYRTP_PROGRESS) {
 					sccp_channel_openReceiveChannel(c);
 				}
-				sccp_dev_displayprompt(d, instance, c->callid, "Call Progress", GLOB(digittimeout));
+				sccp_dev_displayprompt(d, instance, c->callid, SKINNY_DISP_CALL_PROGRESS, GLOB(digittimeout));
 			}
 			break;
 		case SCCP_CHANNELSTATE_PROCEED:
