@@ -8,8 +8,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  * 
- * $Date: 2013-10-17 15:31:03 +0200 (Thu, 17 Oct 2013) $
- * $Revision: 4949 $  
+ * $Date: 2014-06-06 14:25:45 +0200 (Fri, 06 Jun 2014) $
+ * $Revision: 5475 $  
  */
 #ifndef __SCCP_INDICATE_H
 #define __SCCP_INDICATE_H
@@ -17,10 +17,8 @@
 #define SCCP_INDICATE_NOLOCK 	0
 #define SCCP_INDICATE_LOCK		1
 
-void __sccp_indicate(sccp_device_t * device, sccp_channel_t * c, uint8_t state, uint8_t debug, char *file, int line, const char *pretty_function);
-
-const char *sccp_indicate2str(uint8_t state);
-const char *sccp_callstate2str(uint8_t state);
+//void __sccp_indicate(sccp_device_t * device, sccp_channel_t * c, uint8_t state, uint8_t debug, char *file, int line, const char *pretty_function);
+void __sccp_indicate(sccp_device_t * device, sccp_channel_t * c, sccp_channelstate_t state, uint8_t debug, char *file, int line, const char *pretty_function);
 
 #ifdef CS_DEBUG_INDICATIONS
 #define sccp_indicate(x, y, z)	__sccp_indicate(x, y, z, 1, __FILE__, __LINE__, __PRETTY_FUNCTION__)
