@@ -9,8 +9,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  * 		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-06-23 12:43:01 +0200 (Mon, 23 Jun 2014) $
- * $Revision: 5507 $
+ * $Date: 2014-06-27 15:39:53 +0200 (Fri, 27 Jun 2014) $
+ * $Revision: 5531 $
  */
 #ifndef __PBX_IMPL_C
 #define __PBX_IMPL_C
@@ -27,7 +27,7 @@
 #include "sccp_indicate.h"
 #include "sccp_socket.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5507 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5531 $")
 
 /*!
  * \brief SCCP Structure to pass data to the pbx answer thread 
@@ -303,7 +303,7 @@ int sccp_pbx_call(sccp_channel_t * c, char *dest, int timeout)
 
 /*!
  * \brief Handle Hangup Request by Asterisk
- * \param c SCCP Channel
+ * \param channel SCCP Channel
  * \return Success as int
  *
  * \callgraph
@@ -545,8 +545,9 @@ int sccp_pbx_answer(sccp_channel_t * channel)
 
 /*!
  * \brief Allocate an Asterisk Channel
- * \param c SCCP Channel
- * \param linkedId PBX LinkedId which unites related calls under one particular id
+ * \param channel SCCP Channel
+ * \param ids Void Character Pointer (either Empty / LinkedId / Channel ID, depending on the asterisk version)
+ * \param parentChannel SCCP Channel for which the channel was created
  * \return 1 on Success as uint8_t
  *
  * \callgraph
@@ -866,7 +867,7 @@ void *sccp_pbx_softswitch(sccp_channel_t * channel)
 				sccp_device_sendcallstate(d, instance, c->callid, SKINNY_CALLSTATE_PROCEED, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_DEFAULT);
 				sccp_channel_send_callinfo(d, c);
 				sccp_dev_clearprompt(d, instance, c->callid);
-				sccp_dev_displayprompt(d, instance, c->callid, SKINNY_DISP_CALL_PROCEED, 0);
+				sccp_dev_displayprompt(d, instance, c->callid, SKINNY_DISP_CALL_PROCEED, GLOB(digittimeout));
 
 				if (!sccp_strlen_zero(shortenedNumber)) {
 					sccp_log((DEBUGCAT_CORE)) (VERBOSE_PREFIX_3 "SCCP: (sccp_pbx_softswitch) Asterisk request to pickup exten '%s'\n", shortenedNumber);
@@ -929,7 +930,7 @@ void *sccp_pbx_softswitch(sccp_channel_t * channel)
 				sccp_channel_send_callinfo(d, c);
 
 				sccp_dev_clearprompt(d, instance, c->callid);
-				sccp_dev_displayprompt(d, instance, c->callid, SKINNY_DISP_CALL_PROCEED, 0);
+				sccp_dev_displayprompt(d, instance, c->callid, SKINNY_DISP_CALL_PROCEED, GLOB(digittimeout));
 				if (!sccp_strlen_zero(shortenedNumber)) {
 					sccp_log((DEBUGCAT_CORE)) (VERBOSE_PREFIX_3 "%s: (sccp_pbx_softswitch) Device request to barge exten '%s'\n", d->id, shortenedNumber);
 					if (sccp_feat_barge(c, shortenedNumber)) {
@@ -947,7 +948,7 @@ void *sccp_pbx_softswitch(sccp_channel_t * channel)
 				sccp_device_sendcallstate(d, instance, c->callid, SKINNY_CALLSTATE_PROCEED, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_DEFAULT);
 				sccp_channel_send_callinfo(d, c);
 				sccp_dev_clearprompt(d, instance, c->callid);
-				sccp_dev_displayprompt(d, instance, c->callid, SKINNY_DISP_CALL_PROCEED, 0);
+				sccp_dev_displayprompt(d, instance, c->callid, SKINNY_DISP_CALL_PROCEED, GLOB(digittimeout));
 				if (!sccp_strlen_zero(shortenedNumber)) {
 					sccp_log((DEBUGCAT_CORE)) (VERBOSE_PREFIX_3 "%s: (sccp_pbx_softswitch) Device request to barge conference '%s'\n", d->id, shortenedNumber);
 					if (sccp_feat_cbarge(c, shortenedNumber)) {
@@ -1013,7 +1014,7 @@ void *sccp_pbx_softswitch(sccp_channel_t * channel)
 		sccp_channel_send_callinfo(d, c);
 
 		sccp_dev_clearprompt(d, instance, c->callid);
-		sccp_dev_displayprompt(d, instance, c->callid, SKINNY_DISP_CALL_PROCEED, 0);
+		sccp_dev_displayprompt(d, instance, c->callid, SKINNY_DISP_CALL_PROCEED, GLOB(digittimeout));
 #endif
 
 		/*! \todo DdG: Extra wait time is incurred when checking pbx_exists_extension, when a wrong number is dialed. storing extension_exists status for sccp_log use */
