@@ -7,8 +7,8 @@
  * \note                This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *              See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-06-27 12:33:36 +0200 (Fri, 27 Jun 2014) $
- * $Revision: 5527 $
+ * $Date: 2014-06-29 21:56:21 +0200 (Sun, 29 Jun 2014) $
+ * $Revision: 5542 $
  */
 
 #include <config.h>
@@ -579,9 +579,9 @@ static void sccp_protocol_sendOpenReceiveChannelV3(const sccp_device_t * device,
 	if (SCCP_DTMFMODE_SKINNY == channel->dtmfmode) {
 		msg->data.OpenReceiveChannel.v3.lel_RFC2833Type = htolel(0);
 	} else {
-		msg->data.OpenReceiveChannel.v3.lel_RFC2833Type = htolel(SKINNY_CODEC_RFC2833_DYNPAYLOAD);
+		msg->data.OpenReceiveChannel.v3.lel_RFC2833Type = htolel(101);
 	}
-	msg->data.OpenReceiveChannel.v3.lel_dtmfType = htolel(0x0a);
+	msg->data.OpenReceiveChannel.v3.lel_dtmfType = htolel(10);
 
 	sccp_dev_send(device, msg);
 }
@@ -604,9 +604,9 @@ static void sccp_protocol_sendOpenReceiveChannelV17(const sccp_device_t * device
 	if (SCCP_DTMFMODE_SKINNY == channel->dtmfmode) {
 		msg->data.OpenReceiveChannel.v17.lel_RFC2833Type = htolel(0);
 	} else {
-		msg->data.OpenReceiveChannel.v17.lel_RFC2833Type = htolel(SKINNY_CODEC_RFC2833_DYNPAYLOAD);
+		msg->data.OpenReceiveChannel.v17.lel_RFC2833Type = htolel(101);
 	}
-	msg->data.OpenReceiveChannel.v17.lel_dtmfType = htolel(0x0a);
+	msg->data.OpenReceiveChannel.v17.lel_dtmfType = htolel(10);
 
 	struct sockaddr_storage sas;
 //	memcpy(&sas, &device->session->sin, sizeof(struct sockaddr_storage));
@@ -644,9 +644,9 @@ static void sccp_protocol_sendOpenReceiveChannelv22(const sccp_device_t * device
 	if (SCCP_DTMFMODE_SKINNY == channel->dtmfmode) {
 		msg->data.OpenReceiveChannel.v22.lel_RFC2833Type = htolel(0);
 	} else {
-		msg->data.OpenReceiveChannel.v22.lel_RFC2833Type = htolel(SKINNY_CODEC_RFC2833_DYNPAYLOAD);
+		msg->data.OpenReceiveChannel.v22.lel_RFC2833Type = htolel(101);
 	}
-	msg->data.OpenReceiveChannel.v22.lel_dtmfType = htolel(0x0a);
+	msg->data.OpenReceiveChannel.v22.lel_dtmfType = htolel(10);
 
 	struct sockaddr_storage sas;
 //	memcpy(&sas, &device->session->sin, sizeof(struct sockaddr_storage));
@@ -750,9 +750,9 @@ static void sccp_protocol_sendStartMediaTransmissionV3(const sccp_device_t * dev
 	if (SCCP_DTMFMODE_SKINNY == channel->dtmfmode) {
 		msg->data.StartMediaTransmission.v3.lel_RFC2833Type = htolel(0);
 	} else {
-		msg->data.StartMediaTransmission.v3.lel_RFC2833Type = htolel(SKINNY_CODEC_RFC2833_DYNPAYLOAD);
+		msg->data.StartMediaTransmission.v3.lel_RFC2833Type = htolel(101);
 	}
-	msg->data.StartMediaTransmission.v3.lel_dtmfType = htolel(0x0a);
+	msg->data.StartMediaTransmission.v3.lel_dtmfType = htolel(10);
 
 	if(channel->rtp.audio.phone_remote.ss_family == AF_INET){
 		struct sockaddr_in *in = (struct sockaddr_in *)&channel->rtp.audio.phone_remote;
@@ -783,9 +783,9 @@ static void sccp_protocol_sendStartMediaTransmissionV17(const sccp_device_t * de
 	if (SCCP_DTMFMODE_SKINNY == channel->dtmfmode) {
 		msg->data.StartMediaTransmission.v17.lel_RFC2833Type = htolel(0);
 	} else {
-		msg->data.StartMediaTransmission.v17.lel_RFC2833Type = htolel(SKINNY_CODEC_RFC2833_DYNPAYLOAD);
+		msg->data.StartMediaTransmission.v17.lel_RFC2833Type = htolel(101);
 	}
-	msg->data.StartMediaTransmission.v17.lel_dtmfType = htolel(0x0a);
+	msg->data.StartMediaTransmission.v17.lel_dtmfType = htolel(10);
 
 	if (channel->rtp.audio.phone_remote.ss_family == AF_INET6) {
 		struct sockaddr_in6 *in6 = (struct sockaddr_in6 *)&channel->rtp.audio.phone_remote;
@@ -817,9 +817,9 @@ static void sccp_protocol_sendStartMediaTransmissionv22(const sccp_device_t * de
 	if (SCCP_DTMFMODE_SKINNY == channel->dtmfmode) {
 		msg->data.StartMediaTransmission.v22.lel_RFC2833Type = htolel(0);
 	} else {
-		msg->data.StartMediaTransmission.v22.lel_RFC2833Type = htolel(SKINNY_CODEC_RFC2833_DYNPAYLOAD);
+		msg->data.StartMediaTransmission.v22.lel_RFC2833Type = htolel(101);
 	}
-	msg->data.StartMediaTransmission.v22.lel_dtmfType = htolel(0x0a);
+	msg->data.StartMediaTransmission.v22.lel_dtmfType = htolel(10);
 	msg->data.StartMediaTransmission.v22.lel_remotePortNumber = htolel( sccp_socket_getPort(&channel->rtp.audio.phone_remote) );
 	        
 	if (channel->rtp.audio.phone_remote.ss_family == AF_INET6) {
