@@ -8,8 +8,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-05-02 10:04:57 +0200 (Fri, 02 May 2014) $
- * $Revision: 5399 $
+ * $Date: 2014-06-24 13:14:00 +0200 (Tue, 24 Jun 2014) $
+ * $Revision: 5509 $
  */
 #ifndef __SCCP_UTILS_H
 #define __SCCP_UTILS_H
@@ -74,7 +74,7 @@ void sccp_dev_dbclean(void);
 // SCCP Lookups
 gcc_inline const char *msgtype2str(sccp_mid_t type);
 gcc_inline size_t msgtype2size(sccp_mid_t type);
-gcc_inline const char *pbxdevicestate2str(uint32_t value);
+gcc_inline const char *pbxsccp_devicestate2str(uint32_t value);
 gcc_inline const char *extensionstatus2str(uint32_t value);
 
 // SKINNY Lookups
@@ -138,4 +138,5 @@ struct sccp_ha *sccp_append_ha(const char *sense, const char *stuff, struct sccp
 void sccp_print_ha(struct ast_str *buf, int buflen, struct sccp_ha *path);
 void sccp_print_group(struct ast_str *buf, int buflen, sccp_group_t group);
 int sccp_strversioncmp(const char *s1, const char *s2);
+char *sccp_dec2binstr(char *buf, size_t size, int value);
 #endif
